@@ -31,7 +31,7 @@
 
 #include <QDir>
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 #include <QTimer>
 #include <QTimerEvent>
@@ -56,9 +56,9 @@ QUrl replaceVariablesUrl(const QUrl &url, const QString &email)
     }
 
     QString saveStr = url.path();
-    saveStr.replace(QRegExp(QStringLiteral("%[Ee][Mm][Aa][Ii][Ll]%")), email);
-    saveStr.replace(QRegExp(QStringLiteral("%[Nn][Aa][Mm][Ee]%")), emailName);
-    saveStr.replace(QRegExp(QStringLiteral("%[Ss][Ee][Rr][Vv][Ee][Rr]%")), emailHost);
+    saveStr.replace(QRegularExpression(QStringLiteral("%email%"), QRegularExpression::CaseInsensitiveOption), email);
+    saveStr.replace(QRegularExpression(QStringLiteral("%name%"), QRegularExpression::CaseInsensitiveOption), emailName);
+    saveStr.replace(QRegularExpression(QStringLiteral("%server%"), QRegularExpression::CaseInsensitiveOption), emailHost);
 
     QUrl retUrl(url);
     retUrl.setPath(saveStr);
@@ -103,7 +103,7 @@ void FbCheckerJob::dataReceived(KIO::Job *, const QByteArray &data)
 
 void FbCheckerJob::onGetJobFinished(KJob *job)
 {
-    KIO::TransferJob *transferJob = static_cast<KIO::TransferJob *>(job);
+    auto *transferJob = static_cast<KIO::TransferJob *>(job);
     if (mData.contains("BEGIN:VCALENDAR")) {
         qCDebug(AKONADICALENDAR_LOG) << "found freebusy";
         mValidUrl = transferJob->url();
@@ -201,7 +201,7 @@ void FreeBusyManagerPrivate::fetchFreeBusyUrl(const QString &email)
         return;
     }
     // Try with the url configured by preferred email in kcontactmanager
-    Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+    auto *job = new Akonadi::ContactSearchJob();
     job->setQuery(Akonadi::ContactSearchJob::Email, email);
     job->setProperty("contactEmail", QVariant::fromValue(email));
     connect(job, &Akonadi::ContactSearchJob::result, this, &FreeBusyManagerPrivate::contactSearchJobFinished);
@@ -219,7 +219,7 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
         return;
     }
 
-    Akonadi::ContactSearchJob *job = qobject_cast<Akonadi::ContactSearchJob *>(_job);
+    auto *job = qobject_cast<Akonadi::ContactSearchJob *>(_job);
     KConfig cfg(configFile());
     KConfigGroup group = cfg.group(email);
     QString url = group.readEntry(QStringLiteral("url"));
@@ -272,7 +272,7 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
         }
     }
 
-    if (CalendarSettings::self()->freeBusyRetrieveUrl().contains(QRegExp(QStringLiteral("\\.[xiv]fb$")))) {
+    if (CalendarSettings::self()->freeBusyRetrieveUrl().contains(QRegularExpression(QStringLiteral("\\.[xiv]fb$")))) {
         // user specified a fullpath
         // do variable string replacements to the URL (MS Outlook style)
         const QUrl sourceUrl(CalendarSettings::self()->freeBusyRetrieveUrl());
@@ -327,7 +327,7 @@ void FreeBusyManagerPrivate::fbCheckerJobFinished(KJob *job)
 {
     const QString email = job->property("email").toString();
     if (!job->error()) {
-        FbCheckerJob *checkerJob = static_cast<FbCheckerJob *>(job);
+        auto *checkerJob = static_cast<FbCheckerJob *>(job);
         QUrl dirURL = checkerJob->validUrl();
         // write the URL to the cache
         KConfig cfg(configFile());
@@ -379,7 +379,7 @@ void FreeBusyManagerPrivate::processFreeBusyDownloadResult(KJob *_job)
 {
     Q_Q(FreeBusyManager);
 
-    FreeBusyDownloadJob *job = qobject_cast<FreeBusyDownloadJob *>(_job);
+    auto *job = qobject_cast<FreeBusyDownloadJob *>(_job);
     Q_ASSERT(job);
     if (job->error()) {
         qCritical() << "Error downloading freebusy" << _job->errorString();
@@ -423,7 +423,7 @@ void FreeBusyManagerPrivate::processFreeBusyDownloadResult(KJob *_job)
 
 void FreeBusyManagerPrivate::processFreeBusyUploadResult(KJob *_job)
 {
-    KIO::FileCopyJob *job = static_cast<KIO::FileCopyJob *>(_job);
+    auto *job = static_cast<KIO::FileCopyJob *>(_job);
     if (job->error()) {
         KMessageBox::sorry(
             nullptr,
@@ -481,7 +481,7 @@ void FreeBusyManagerPrivate::finishProcessRetrieveQueue(const QString &email, co
 
     mFreeBusyUrlEmailMap.insert(freeBusyUrlForEmail, email);
 
-    FreeBusyDownloadJob *job = new FreeBusyDownloadJob(freeBusyUrlForEmail, mParentWidgetForRetrieval);
+    auto *job = new FreeBusyDownloadJob(freeBusyUrlForEmail, mParentWidgetForRetrieval);
     q->connect(job, &FreeBusyDownloadJob::result, this, [this](KJob *job) {
         processFreeBusyDownloadResult(job);
     });
@@ -583,7 +583,7 @@ void FreeBusyManagerPrivate::onHandlesFreeBusy(const QString &email, bool handle
         return;
     }
 
-    QDBusInterface *iface = dynamic_cast<QDBusInterface *>(sender());
+    auto *iface = dynamic_cast<QDBusInterface *>(sender());
     if (!iface) {
         return;
     }
@@ -649,7 +649,7 @@ void FreeBusyManagerPrivate::onFreeBusyRetrieved(const QString &email, const QSt
         return;
     }
 
-    QDBusInterface *iface = dynamic_cast<QDBusInterface *>(sender());
+    auto *iface = dynamic_cast<QDBusInterface *>(sender());
     if (!iface) {
         return;
     }
@@ -805,7 +805,7 @@ void FreeBusyManager::publishFreeBusy(QWidget *parentWidget)
 
     // We need to massage the list a bit so that Outlook understands
     // it.
-    messageText.replace(QRegExp(QStringLiteral("ORGANIZER\\s*:MAILTO:")),
+    messageText.replace(QRegularExpression(QStringLiteral("ORGANIZER\\s*:MAILTO:")),
                         QStringLiteral("ORGANIZER:"));
 
     // Create a local temp file and save the message to it
@@ -885,7 +885,7 @@ void FreeBusyManager::mailFreeBusy(int daysToPublish, QWidget *parentWidget)
     QPointer<PublishDialog> publishdlg = new PublishDialog();
     if (publishdlg->exec() == QDialog::Accepted) {
         // Send the mail
-        MailScheduler *scheduler = new MailScheduler(/*factory=*/ nullptr, this);
+        auto *scheduler = new MailScheduler(/*factory=*/ nullptr, this);
         connect(scheduler, &Scheduler::transactionFinished,
                 d, &FreeBusyManagerPrivate::processMailSchedulerResult);
         d->mParentWidgetForMailling = parentWidget;
